@@ -222,7 +222,7 @@ class Application(object):
 
         debug("config:%s" % repr(self.config))
         self.hosts          = self.config['hosts']
-        self.root           = Path(self.config['root'])
+        self.root           = Path(os.path.expanduser(self.config['root']))
         self.repositories   = self.config['repositories']
         self.exclude        = self.config['exclude']
         self.export         = self.config['export']
